@@ -17,7 +17,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 log = logging.getLogger(__name__)
 
-from bokeh.util.api import public, internal ; public, internal
+from bokeh.util.api import general, dev ; general, dev
 
 #-----------------------------------------------------------------------------
 # Imports
@@ -34,13 +34,16 @@ from .saving import save
 from .state import curstate
 
 #-----------------------------------------------------------------------------
-# Public API
+# General API
 #-----------------------------------------------------------------------------
 
-@public((1,0,0))
+@general((1,0,0))
 def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="localhost:8888"):
     ''' Immediately display a Bokeh object or application.
 
+        :func:`show` may be called multiple times in a single Jupyter notebook
+        cell to display multiple objects. The objects are displayed in order.
+
     Args:
         obj (LayoutDOM or Application) :
             A Bokeh object to display.
@@ -96,6 +99,11 @@ def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="loca
             standard checks, so that applications will display regardless of
             the current notebook location, however a warning will appear.
 
+            notebook_url can also be a function that takes one int for the
+            bound server port.  If the port is provided, the function needs
+            to generate the full public URL to the bokeh server.  If None
+            is passed, the function is to generate the origin URL.
+
 
     Some parameters are only useful when certain output modes are active:
 
@@ -129,7 +137,7 @@ def show(obj, browser=None, new="tab", notebook_handle=False, notebook_url="loca
     return _show_with_state(obj, state, browser, new, notebook_handle=notebook_handle)
 
 #-----------------------------------------------------------------------------
-# Internal API
+# Dev API
 #-----------------------------------------------------------------------------
 
 #-----------------------------------------------------------------------------
