@@ -8,9 +8,9 @@ from ..core.has_props import abstract
 from ..core.properties import Auto, Datetime, Dict, Either, Enum, Float, Include, Instance, Int, Override, Seq, String, Tuple
 from ..core.property_mixins import LineProps, TextProps
 
-from .formatters import BasicTickFormatter, CategoricalTickFormatter, DatetimeTickFormatter, LogTickFormatter, TickFormatter
+from .formatters import BasicTickFormatter, CategoricalTickFormatter, DatetimeTickFormatter, LogTickFormatter, TickFormatter, MercatorTickFormatter
 from .renderers import GuideRenderer
-from .tickers import Ticker, BasicTicker, LogTicker, CategoricalTicker, DatetimeTicker, FixedTicker
+from .tickers import Ticker, BasicTicker, LogTicker, CategoricalTicker, DatetimeTicker, FixedTicker, MercatorTicker
 
 @abstract
 class Axis(GuideRenderer):
@@ -179,6 +179,30 @@ class CategoricalAxis(Axis):
 
     formatter = Override(default=lambda: CategoricalTickFormatter())
 
+    separator_props = Include(LineProps, help="""
+    The %s of the separator line between top-level categorical groups.
+    """)
+
+    separator_line_color = Override(default="lightgrey")
+
+    separator_line_width = Override(default=2)
+
+    group_props = Include(TextProps, help="""
+    The %s of the group top-level categorical groups.
+    """)
+
+    group_text_font_size = Override(default={'value': "8pt"})
+    group_text_font_style = Override(default="bold")
+    group_text_color = Override(default="grey")
+
+    subgroup_props = Include(TextProps, help="""
+    The %s of the group top-level categorical groups.
+    """)
+
+    subgroup_text_font_size = Override(default={'value': "8pt"})
+    subgroup_text_font_style = Override(default="bold")
+
+
 class DatetimeAxis(LinearAxis):
     ''' An LinearAxis that picks nice numbers for tick locations on
     a datetime scale. Configured with a ``DatetimeTickFormatter`` by
@@ -189,3 +213,27 @@ class DatetimeAxis(LinearAxis):
     ticker = Override(default=lambda: DatetimeTicker())
 
     formatter = Override(default=lambda: DatetimeTickFormatter())
+
+class MercatorAxis(LinearAxis):
+    ''' An axis that picks nice numbers for tick locations on a
+    Mercator scale. Configured with a ``MercatorTickFormatter`` by default.
+
+    Args:
+        dimension ('lat' or 'lon', optional) :
+            Whether this axis will display latitude or longitude values.
+            (default: 'lat')
+
+    '''
+    def __init__(self, dimension='lat', **kw):
+        super(MercatorAxis, self).__init__(**kw)
+
+        # Just being careful. It would be defeat the purpose for anyone to actually
+        # configure this axis with differnet kinds of tickers or formatters.
+        if isinstance(self.ticker, MercatorTicker):
+            self.ticker.dimension = dimension
+        if isinstance(self.formatter, MercatorTickFormatter):
+            self.formatter.dimension = dimension
+
+    ticker = Override(default=lambda: MercatorTicker())
+
+    formatter = Override(default=lambda: MercatorTickFormatter())
