@@ -9,7 +9,7 @@ from ..core.property_mixins import LineProps, FillProps
 from ..core.query import find
 from ..core.validation import error, warning
 from ..core.validation.errors import REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
-from ..core.validation.warnings import MISSING_RENDERERS, NO_DATA_RENDERERS
+from ..core.validation.warnings import MISSING_RENDERERS
 from ..util.deprecation import deprecated
 from ..util.plot_utils import _list_attr_splat, _select_helper
 from ..util.string import nice_join
@@ -20,7 +20,7 @@ from .glyphs import Glyph
 from .grids import Grid
 from .layouts import LayoutDOM
 from .ranges import Range, FactorRange, DataRange1d, Range1d
-from .renderers import DataRenderer, DynamicImageRenderer, GlyphRenderer, Renderer, TileRenderer
+from .renderers import GlyphRenderer, Renderer, TileRenderer
 from .scales import Scale, CategoricalScale, LinearScale, LogScale
 from .sources import DataSource, ColumnDataSource
 from .tools import Tool, Toolbar
@@ -304,24 +304,6 @@ class Plot(LayoutDOM):
         self.renderers.append(tile_renderer)
         return tile_renderer
 
-    def add_dynamic_image(self, image_source, **kw):
-        ''' Adds new DynamicImageRenderer into the Plot.renderers
-
-        Args:
-            image_source (ImageSource) : a image source instance which contain image configuration
-
-        Keyword Arguments:
-            Additional keyword arguments are passed on as-is to the dynamic image renderer
-
-        Returns:
-            DynamicImageRenderer : DynamicImageRenderer
-
-        '''
-        deprecated((0, 12, 7), "add_dynamic_image", "GeoViews for GIS functions on top of Bokeh (http://geo.holoviews.org)")
-        image_renderer = DynamicImageRenderer(image_source=image_source, **kw)
-        self.renderers.append(image_renderer)
-        return image_renderer
-
     @error(REQUIRED_RANGE)
     def _check_required_range(self):
         missing = []
@@ -372,11 +354,6 @@ class Plot(LayoutDOM):
         if len(self.renderers) == 0:
             return str(self)
 
-    @warning(NO_DATA_RENDERERS)
-    def _check_no_data_renderers(self):
-        if len(self.select(DataRenderer)) == 0:
-            return str(self)
-
     x_range = Instance(Range, help="""
     The (default) data range of the horizontal dimension of the plot.
     """)
@@ -656,6 +633,10 @@ class Plot(LayoutDOM):
         setting only sets the initial plot draw and subsequent resets. It is
         possible for tools (single axis zoom, unconstrained box zoom) to
         change the aspect ratio.
+
+    .. warning::
+        This setting is incompatible with linking dataranges across multiple
+        plots. Doing so may result in undefined behaviour.
     """)
 
     aspect_scale = Float(default=1, help="""
