@@ -12,7 +12,7 @@ import sys
 from six import string_types, reraise
 
 from ..models import (
-    BoxSelectTool, BoxZoomTool, CategoricalAxis,
+    BoxSelectTool, BoxZoomTool, CategoricalAxis, MercatorAxis,
     TapTool, CrosshairTool, DataRange1d, DatetimeAxis,
     FactorRange, Grid, HelpTool, HoverTool, LassoSelectTool, Legend, LegendItem, LinearAxis,
     LogAxis, PanTool, ZoomInTool, ZoomOutTool, PolySelectTool, ContinuousTicker,
@@ -20,6 +20,7 @@ from ..models import (
     WheelPanTool, WheelZoomTool, ColumnarDataSource, ColumnDataSource,
     LogScale, LinearScale, CategoricalScale, Circle, MultiLine,
     BoxEditTool, PointDrawTool, PolyDrawTool, PolyEditTool)
+from bokeh.models.markers import Marker
 from ..models.renderers import GlyphRenderer
 
 from ..core.properties import ColorSpec, Datetime, value, field
@@ -265,7 +266,7 @@ Pass all data directly as literals:
 Or, put all data in a ColumnDataSource and pass column names:
 
     source = ColumnDataSource(data=dict(x=a_list, y=an_array))
-    p.circe(x='x', y='x', source=source, ...)
+    p.circe(x='x', y='y', source=source, ...)
 
 """
 
@@ -357,7 +358,7 @@ def _get_range(range_input):
 
 
 def _get_scale(range_input, axis_type):
-    if isinstance(range_input, (DataRange1d, Range1d)) and axis_type in ["linear", "datetime", "auto", None]:
+    if isinstance(range_input, (DataRange1d, Range1d)) and axis_type in ["linear", "datetime", "mercator", "auto", None]:
         return LinearScale()
     elif isinstance(range_input, (DataRange1d, Range1d)) and axis_type == "log":
         return LogScale()
@@ -367,26 +368,28 @@ def _get_scale(range_input, axis_type):
         raise ValueError("Unable to determine proper scale for: '%s'" % str(range_input))
 
 
-def _get_axis_class(axis_type, range_input):
+def _get_axis_class(axis_type, range_input, dim):
     if axis_type is None:
-        return None
+        return None, {}
     elif axis_type == "linear":
-        return LinearAxis
+        return LinearAxis, {}
     elif axis_type == "log":
-        return LogAxis
+        return LogAxis, {}
     elif axis_type == "datetime":
-        return DatetimeAxis
+        return DatetimeAxis, {}
+    elif axis_type == "mercator":
+        return MercatorAxis, {'dimension': 'lon' if dim == 0 else 'lat'}
     elif axis_type == "auto":
         if isinstance(range_input, FactorRange):
-            return CategoricalAxis
+            return CategoricalAxis, {}
         elif isinstance(range_input, Range1d):
             try:
                 # Easier way to validate type of Range1d parameters
                 Datetime.validate(Datetime(), range_input.start)
-                return DatetimeAxis
+                return DatetimeAxis, {}
             except ValueError:
                 pass
-        return LinearAxis
+        return LinearAxis, {}
     else:
         raise ValueError("Unrecognized axis_type: '%r'" % axis_type)
 
@@ -468,19 +471,11 @@ def _tool_from_string(name):
 
 
 def _process_axis_and_grid(plot, axis_type, axis_location, minor_ticks, axis_label, rng, dim):
-    axiscls = _get_axis_class(axis_type, rng)
+    axiscls, axiskw = _get_axis_class(axis_type, rng, dim)
     if axiscls:
 
-        if axiscls is LogAxis:
-            if dim == 0:
-                plot.x_scale = LogScale()
-            elif dim == 1:
-                plot.y_scale = LogScale()
-            else:
-                raise ValueError("received invalid dimension value: %r" % dim)
-
         # this is so we can get a ticker off the axis, even if we discard it
-        axis = axiscls(plot=plot if axis_location else None)
+        axis = axiscls(plot=plot if axis_location else None, **axiskw)
 
         if isinstance(axis.ticker, ContinuousTicker):
             axis.ticker.num_minor_ticks = _get_num_minor_ticks(axiscls, minor_ticks)
@@ -639,7 +634,7 @@ def _get_sigfunc(func_name, func, argspecs):
 _arg_template = """    %s (%s) : %s
         (default: %r)
 """
-_doc_template = """ Configure and add %s glyphs to this Figure.
+_doc_template = """ Configure and add :class:`~bokeh.models.%s.%s` glyphs to this Figure.
 
 Args:
 %s
@@ -665,7 +660,7 @@ Returns:
 """
 
 def _add_sigfunc_info(func, argspecs, glyphclass, extra_docs):
-    func.__name__ = glyphclass.__name__.lower()
+    func.__name__ = glyphclass.__name__
 
     omissions = {'js_event_callbacks', 'js_property_callbacks', 'subscribed_events'}
 
@@ -691,7 +686,8 @@ def _add_sigfunc_info(func, argspecs, glyphclass, extra_docs):
     for arg, spec in argspecs.items():
         arglines.append(_arg_template % (arg, spec['type'], spec['desc'], spec['default']))
 
-    func.__doc__ = _doc_template % (func.__name__, "\n".join(arglines), "\n".join(kwlines))
+    mod = "markers" if issubclass(glyphclass, Marker) else "glyphs"
+    func.__doc__ = _doc_template % (mod, func.__name__, "\n".join(arglines), "\n".join(kwlines))
     if extra_docs:
         func.__doc__ += extra_docs
 
@@ -724,6 +720,10 @@ def _glyph_function(glyphclass, extra_docs=None):
         renderer_kws = _pop_renderer_args(kwargs)
         source = renderer_kws['data_source']
 
+        # Assign global_alpha from alpha if glyph type is an image
+        if 'alpha' in kwargs and glyphclass.__name__ in ('Image', 'ImageRGBA', 'ImageURL'):
+            kwargs['global_alpha'] = kwargs['alpha']
+
         # handle the main glyph, need to process literals
         glyph_ca = _pop_colors_and_alpha(glyphclass, kwargs)
         _process_sequence_literals(glyphclass, kwargs, source, is_user_source)
